## Computer positioning

### Description

The data represent consumer evaluations for a set of computers on 7 attributes. 

### Variables

A data frame with 5 rows of data on 8 variables. All numbers are averages across respondents.

- brand = The computer brand name
- high_end = Is the brand perceived to be highend (1-9), where 1 is not at all highend and 9 is very highend
- stylish = Is the brand perceived to be stylish (1-9), where 1 is not at all stylish and 9 is very stylish
- modern = Is the brand perceived as modern (1-9), where 1 is not at all modern and 9 is very modern
- value = Is the brand perceived to offer good value (1-9), where 1 is not at all good value and 9 is very good value
- dated = Is the brand perceived to have a dated look (1-9), where 1 is not at all dated and 9 is very dated
- innovative = Is the brand perceived to an innovation leader (1-9), where 1 is not at all and 9 is very much
- business = Is the brand perceived to have a business orientation (1-9), where 1 is not at all and 9 is very much
